netapp_ontap.models.workspace_version_workspace API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.workspace_version_workspace`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class WorkspaceVersionWorkspaceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the WorkspaceVersionWorkspace object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `create_time: ImpreciseDateTime GET`

    The creation time of the workspace version.

    Example: 2018-06-04T19:00:00.000+0000

  `data_collection_count: Size GET`

    The count of data collection in a workspace.

    Example: 20

  `description: str GET`

    The description of the workspace.

    Example: Example workspace

  `entity_count: Size GET`

    The count of entities in a workspace.

    Example: 1000

  `errors: List[DataEngineEntityErrors] GET`

    The errors field of the workspace_version_workspace.

  `message: str GET`

    The message associated with the current state of the workspace.

    Example: creating workspace

  `name: str GET`

    The name of the workspace.

    Example: Doc workspace

  `owner: str GET`

    The owner of the workspace.

    Example: SAL

  `policies: List[WorkspaceVersionWorkspacePolicies] GET`

    The policies field of the workspace_version_workspace.

  `refresh_interval: str GET`

    The workspace refresh time interval in ISO-8601 format.

    Example: PT1H

  `space: WorkspaceVersionWorkspaceSpace GET`

    The space detail of a workspace.

  `state: str GET`

    State of the workspace version:

    - processing - The workspace is being processed after creation.
    - ready - The workspace is ready for use.
    - failed - The workspace has a failure.
    - outdated - The workspace is outdated.
    - Valid in GET.

    Valid choices:

    - processing
    - ready
    - failed
    - outdated
  `uuid: str GET`

    The unique identifier of the workspace.

    Example: 4ea7a442-86d1-11e0-ae1c-123478563412

  `version: WorkspaceVersionWorkspaceVersion GET`

    The version information of a workspace.